package com.bonus.material.ma.service;

import java.util.List;
import com.bonus.material.ma.domain.TypeNumHis;

/**
 * 机具类型历史库存Service接口
 * 
 * @author xsheng
 * @date 2024-09-27
 */
public interface ITypeNumHisService 
{
    /**
     * 查询机具类型历史库存
     * 
     * @param typeId 机具类型历史库存主键
     * @return 机具类型历史库存
     */
    public TypeNumHis selectTypeNumHisByTypeId(Long typeId);

    /**
     * 查询机具类型历史库存列表
     * 
     * @param typeNumHis 机具类型历史库存
     * @return 机具类型历史库存集合
     */
    public List<TypeNumHis> selectTypeNumHisList(TypeNumHis typeNumHis);

    /**
     * 新增机具类型历史库存
     * 
     * @param typeNumHis 机具类型历史库存
     * @return 结果
     */
    public int insertTypeNumHis(TypeNumHis typeNumHis);

    /**
     * 修改机具类型历史库存
     * 
     * @param typeNumHis 机具类型历史库存
     * @return 结果
     */
    public int updateTypeNumHis(TypeNumHis typeNumHis);

    /**
     * 批量删除机具类型历史库存
     * 
     * @param typeIds 需要删除的机具类型历史库存主键集合
     * @return 结果
     */
    public int deleteTypeNumHisByTypeIds(Long[] typeIds);

    /**
     * 删除机具类型历史库存信息
     * 
     * @param typeId 机具类型历史库存主键
     * @return 结果
     */
    public int deleteTypeNumHisByTypeId(Long typeId);
}
