package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.TypeNumHis;
import com.bonus.material.ma.service.ITypeNumHisService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 机具类型历史库存Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "机具类型历史库存接口")
@RestController
@RequestMapping("/ma_type_num_his")
public class TypeNumHisController extends BaseController
{
    @Autowired
    private ITypeNumHisService typeNumHisService;

    /**
     * 查询机具类型历史库存列表
     */
    @ApiOperation(value = "查询机具类型历史库存列表")
    @RequiresPermissions("ma:his:list")
    @GetMapping("/list")
    public TableDataInfo list(TypeNumHis typeNumHis)
    {
        startPage();
        List<TypeNumHis> list = typeNumHisService.selectTypeNumHisList(typeNumHis);
        return getDataTable(list);
    }

    /**
     * 导出机具类型历史库存列表
     */
    @ApiOperation(value = "导出机具类型历史库存列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:his:export")
    @SysLog(title = "机具类型历史库存", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出机具类型历史库存")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TypeNumHis typeNumHis)
    {
        List<TypeNumHis> list = typeNumHisService.selectTypeNumHisList(typeNumHis);
        ExcelUtil<TypeNumHis> util = new ExcelUtil<TypeNumHis>(TypeNumHis.class);
        util.exportExcel(response, list, "机具类型历史库存数据");
    }

    /**
     * 获取机具类型历史库存详细信息
     */
    @ApiOperation(value = "获取机具类型历史库存详细信息")
    @RequiresPermissions("ma:his:query")
    @GetMapping(value = "/{typeId}")
    public AjaxResult getInfo(@PathVariable("typeId") Long typeId)
    {
        return success(typeNumHisService.selectTypeNumHisByTypeId(typeId));
    }

    /**
     * 新增机具类型历史库存
     */
    @ApiOperation(value = "新增机具类型历史库存")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:his:add")
    @SysLog(title = "机具类型历史库存", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增机具类型历史库存")
    @PostMapping
    public AjaxResult add(@RequestBody TypeNumHis typeNumHis)
    {
        return toAjax(typeNumHisService.insertTypeNumHis(typeNumHis));
    }

    /**
     * 修改机具类型历史库存
     */
    @ApiOperation(value = "修改机具类型历史库存")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:his:edit")
    @SysLog(title = "机具类型历史库存", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改机具类型历史库存")
    @PutMapping
    public AjaxResult edit(@RequestBody TypeNumHis typeNumHis)
    {
        return toAjax(typeNumHisService.updateTypeNumHis(typeNumHis));
    }

    /**
     * 删除机具类型历史库存
     */
    @ApiOperation(value = "删除机具类型历史库存")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:his:remove")
    @SysLog(title = "机具类型历史库存", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除机具类型历史库存")
	@DeleteMapping("/{typeIds}")
    public AjaxResult remove(@PathVariable Long[] typeIds)
    {
        return toAjax(typeNumHisService.deleteTypeNumHisByTypeIds(typeIds));
    }
}
